#procedure ctfeynmanrules()

* This file is part of aITALC
* Copyright (C) 2004 Alejandro Lorca <alejandro.lorca@desy.de>
*------------------------------------------------------------- 
** Procedure to apply Feynman Rules with counter-terms to Diana Output
** Revisited begun on 19/08/03

.sort
nwrite statistics;

* Counter-term propagators (last number=10)
* They receive a factor 2 to restore the symmetry scalar loop factor 1/2
#do i=1,`LINE'
  id SS(`i',10) = 2;
#enddo

* propagators
* unshifted poles

#do i=1,`LINE'
  id SS(`i',0) = 1/c`i';
  id FF(`i',c?,p1?,a?) = (gamma(c,p1)+ident(c)*a)/c`i';
#enddo

#if `FGAUGE'==1

*
* FEYNMAN GAUGE
*
  id xig^x? = 1;
  id xiA^x? = 1;
  id xiW^x? = 1;
  id xiZ^x? = 1;

  #do i=1,`LINE'
    id SS(`i',c?!{,0}) = 1/c`i';

    id VV(`i',mu1?,mu2?,q?,0) = -d_(mu1,mu2)/c`i';
    id VV(`i',mu1?,mu2?,q?,1) = -d_(mu1,mu2)/c`i';
    id VV(`i',mu1?,mu2?,q?,2) = -d_(mu1,mu2)/c`i';
    id VV(`i',mu1?,mu2?,q?,3) = -d_(mu1,mu2)/c`i';
    .sort
  #enddo

#else

*
*  ARBITRARY GAUGE: shifted poles
*
  #do i=1,`LINE'
  id SS(`i',c?!{,0}) = 1/cxi`i';
  
  id VV(`i',mu1?,mu2?,q?,0) = -d_(mu1,mu2)/c`i'
                              +(1-xiA)*q(mu1)*q(mu2)/(c`i'*cxi`i');
  id VV(`i',mu1?,mu2?,q?,1) = -d_(mu1,mu2)/c`i'
                              +(1-xiZ)*q(mu1)*q(mu2)/(c`i'*cxi`i');
  id VV(`i',mu1?,mu2?,q?,2) = -d_(mu1,mu2)/c`i'
                              +(1-xiW)*q(mu1)*q(mu2)/(c`i'*cxi`i');
  id VV(`i',mu1?,mu2?,q?,3) = -d_(mu1,mu2)/c`i'
                              +(1-xig)*q(mu1)*q(mu2)/(c`i'*cxi`i');
  .sort
  #enddo
#endif

* scalar vertex
id V(s?,0) = 1;

* vector vertex
id V(s?,mu1?,q?,1) = q(mu1);

* tensor2 vertex
id V(s?,mu1?,mu2?,2) = d_(mu1,mu2);

* VVV vertex
id V(s?,mu1?,mu2?,mu3?,p1?,p2?,p3?,3) =
   (
    +(p1(mu3)-p2(mu3))*d_(mu1,mu2)
    +(p2(mu1)-p3(mu1))*d_(mu2,mu3)
    +(p3(mu2)-p1(mu2))*d_(mu3,mu1)
   );

* VVVV vertex
id V(s?,mu1?,mu2?,mu3?,mu4?,4) = 
   (
    +2*d_(mu1,mu2)*d_(mu3,mu4)
    -d_(mu1,mu3)*d_(mu2,mu4)
    -d_(mu1,mu4)*d_(mu2,mu3)
   );

* fermion-(axial)vector-fermion
id F(s?,c?,mu1?,GVl?,GAl?,1) =
    gamma(c,mu1)*(GVl*ident(c) + GAl*gamma5(c));
 
 
* fermion-(pseudo)scalar-fermion
id F(s?,c?,GVl?,GAl?,0) = GVl*ident(c) + GAl*gamma5(c);

.sort

id 1/sqrt2^2 = 1/2;

.sort
#endprocedure ctfeynmanrules
*$Id: ctfeynmanrules.prc,v 1.5 2004/10/29 13:07:26 alorca Exp $
